@@ -9,11 +9,11 @@ use File::Slurp;
 use MIME::Base64;
 use Crypt::OpenSSL::RSA;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 sub _info {
   {
-    'info_version'      => '0.01',
+    'info_compat'       => '0.01',
     'module_version'    => $VERSION,
     'supported_types'   => [ 'CC' ],
     'supported_actions' => { 'CC' => [
@@ -22,6 +22,7 @@ sub _info {
                                        'Post Authorization',
                                        'Void',
                                        'Credit',
+                                       'Tokenize',
                                      ],
                            },
     'token_support'     => 1,
@@ -41,7 +42,7 @@ sub set_defaults {
 
   $self->build_subs(qw( order_number avs_code cvv2_response
                         response_page response_code response_headers
-                        card_token private_key
+                        card_token private_key txn_date
                    ));
 }
 
@@ -53,6 +54,8 @@ sub submit {
   my %content = $self->content;
   $content{$_} = $self->$_() for qw( gateway gateway_login gateway_password );
 
+  $content{$_} = $self->$_() for grep $self->can($_), qw( bop_options );
+
   my ($page,$server_response,%headers) = $self->https_post(%content);
 
   die "$server_response\n" unless $server_response =~ /^200/;
@@ -70,6 +73,7 @@ sub submit {
                fraud_score fraud_transaction_id
                result_code avs_code cvv2_response
                card_token
+               txn_date
              )) {
     $self->$_($response{$_});
   }
@@ -160,6 +164,7 @@ Business::OnlinePayment::CardFortress - CardFortress backend for Business::Onlin
       'gateway_login'    => 'gwlogin',
       'gateway_password' => 'gwpass',
       'private_key'      => $private_key_string, #or filename
+      'bop_options'      => join('/', map "$_=".$options{$_}, keys %options),
   );
 
   $rx->content(
@@ -213,7 +218,7 @@ Ivan Kohler C<< <ivan-bop-cardfortress at freeside.biz> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008-2010 Freeside Internet Services, Inc. (http://freeside.biz/)
+Copyright 2008-2016 Freeside Internet Services, Inc. (http://freeside.biz/)
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
